@@ -55,10 +55,24 @@
 #' Only used if \code{all.pairwise=FALSE}.
 #' @param num.threads Integer scalar specifying the number of threads to use.
 #'
-#' @return If \code{all.pairwise=FALSE}, a named list is returned containing:
+#' @return
+#' A named list containing:
 #' \itemize{
-#' \item \code{cohens.d}, a list of data frames where each data frame corresponds to a group.
-#' Each row of each data frame represents a gene, while each column contains a summary of Cohen's d from pairwise comparisons to all other groups.
+#' \item \code{nrow}, integer specifying the number of rows in \code{x}.
+#' \item \code{row.names}, character vector or \code{NULL} containing the row names of \code{x}.
+#' \item \code{group.ids}, vector contaning the identities of the unique groups.
+#' \item \code{mean}, a numeric matrix containing the mean expression for each group.
+#' Each row is a gene and each column is a group in \code{group.ids}.
+#' Omitted if \code{compute.group.mean=FALSE}.
+#' \item \code{detected}, a numeric matrix containing the proportion of detected cells in each group.
+#' Each row is a gene and each column is a group in \code{group.ids}.
+#' Omitted if \code{compute.group.detected=FALSE}.
+#' }
+#' 
+#' If \code{all.pairwise=FALSE}, the list also contains:
+#' \itemize{
+#' \item \code{cohens.d}, a list of \link[S4Vectors]{DataFrame}s where each DataFrame corresponds to a group in \code{group.ids}.
+#' Each row of a DataFrame represents a gene, while each column contains a summary of Cohen's d from pairwise comparisons to all other groups.
 #' This includes \code{min}, \code{mean}, \code{median}, \code{max}, \code{quantile.*} and \code{min.rank} - check out \code{?\link{summarizeEffects}} for details.
 #' Omitted if \code{compute.cohens.d=FALSE}.
 #' \item \code{auc}, a list like \code{cohens.d} but containing the summaries of the AUCs from each pairwise comparison.
@@ -69,11 +83,11 @@
 #' Omitted if \code{compute.delta.detected=FALSE}.
 #' }
 #'
-#' If \code{all.pairwise=TRUE}, a named list is returned containing:
+#' If \code{all.pairwise=TRUE}, the list also contains:
 #' \itemize{
 #' \item \code{cohens.d}, a 3-dimensional numeric array containing the Cohen's d from each pairwise comparison between groups.
-#' The extents of the first two dimensions are equal to the number of groups, while the extent of the final dimension is equal to the number of genes.
-#' The entry \code{[i, j, k]} represents Cohen's d from the comparison of group \code{j} over group \code{i} for gene \code{k}.
+#' The extents of the first two dimensions are equal to the number of groups in \code{group.ids}, while the extent of the final dimension is equal to the number of genes.
+#' The entry \code{cohens.d[i, j, k]} represents Cohen's d from the comparison of group \code{group.ids[j]} over group \code{group.ids[i]} for gene \code{k}.
 #' Omitted if \code{compute.cohens.d=FALSE}.
 #' \item \code{auc}, an array like \code{cohens.d} but containing the AUCs from each pairwise comparison.
 #' Omitted if \code{compute.auc=FALSE}.
@@ -83,29 +97,21 @@
 #' Omitted if \code{compute.delta.detected=FALSE}.
 #' }
 #'
-#' If \code{all.pairwise} is an integer, a named list is returned containing:
+#' If \code{all.pairwise} is an integer, the list also contains:
 #' \itemize{
-#' \item \code{cohens.d}, a list of list of data frames containing the top genes with the largest Cohen's d for each pairwise comparison.
-#' Specifically, \code{cohens.d[[i]][[j]]} is a data frame contains the top \code{all.pairwise} genes from the comparison of group \code{i} over group \code{j}. 
-#' Each data frame contains \code{index}, the row index of the gene; and \code{effect}, the Cohen's d for that gene.
+#' \item \code{cohens.d}, a list of list of \link[S4Vectors]{DataFrame}s containing the top genes with the largest Cohen's d for each pairwise comparison.
+#' Specifically, \code{cohens.d[[i]][[j]]} is a DataFrame that contains the top \code{all.pairwise} genes from the comparison of group \code{group.ids[i]} over group \code{group.ids[j]}. 
+#' Each DataFrame contains an \code{index} column, the row index of the gene; and an \code{effect} column, the Cohen's d for that gene.
 #' Omitted if \code{compute.cohens.d=FALSE}.
-#' \item \code{auc}, a list of list of data frames like \code{cohens.d} but containing the AUCs from each pairwise comparison.
+#' \item \code{auc}, a list of list of DataFrames like \code{cohens.d} but containing the AUCs from each pairwise comparison.
 #' Omitted if \code{compute.auc=FALSE}.
-#' \item \code{delta.mean}, a list of list of data frames like \code{cohens.d} but containing the delta-mean from each pairwise comparison.
+#' \item \code{delta.mean}, a list of list of DataFrames like \code{cohens.d} but containing the delta-mean from each pairwise comparison.
 #' Omitted if \code{compute.delta.mean=FALSE}.
-#' \item \code{delta.detected}, a list of list of data frames like \code{cohens.d} but containing the delta-detected from each pairwise comparison.
+#' \item \code{delta.detected}, a list of list of DataFrames like \code{cohens.d} but containing the delta-detected from each pairwise comparison.
 #' Omitted if \code{compute.delta.detected=FALSE}.
 #' }
 #'
 #' All returned lists will also contain:
-#' \itemize{
-#' \item \code{mean}, a numeric matrix containing the mean expression for each group.
-#' Each row is a gene and each column is a group.
-#' Omitted if \code{compute.group.mean=FALSE}.
-#' \item \code{detected}, a numeric matrix containing the proportion of detected cells in each group.
-#' Each row is a gene and each column is a group.
-#' Omitted if \code{compute.group.detected=FALSE}.
-#' }
 #'
 #' @section Choice of effect size:
 #' The delta-mean is the difference in the mean expression between groups.
@@ -174,6 +180,7 @@
 #'
 #' @export
 #' @importFrom beachmat initializeCpp
+#' @importFrom S4Vectors DataFrame
 scoreMarkers <- function(
     x, 
     groups, 
@@ -271,6 +278,10 @@ scoreMarkers <- function(
         }
     }
 
+    output$nrow <- ngenes
+    output$row.names <- rn
+    output$group.ids <- groups$names
+
     if (compute.group.mean) {
         dimnames(output$mean) <- list(rn, groups$names)
     }
