@@ -2,12 +2,13 @@
     if (is.null(f)) {
         list(index=NULL, names=NULL)
     } else {
-        f <- factor(f)
-        list(index=as.integer(f) - 1L, names=levels(f))
+        # Don't use 'factor', to preserve the type of 'f' in the 'names'.
+        lev <- sort(unique(f))
+        list(index=match(f, lev) - 1L, names=lev)
     }
 }
 
-.checkNeighborIndices <- function(index, num.neighbors) {
+.checkNeighborResults <- function(index, distance) {
     stopifnot(length(dim(index)) == 2L)
     r <- range(index)
     if (!is.finite(r[1]) || r[1] < 1L) {
@@ -16,8 +17,8 @@
     if (!is.finite(r[2]) || r[2] > ncol(index)) {
         stop("'index' should contain finite integers no greater than 'ncol(index)'")
     }
-    if (nrow(index) != num.neighbors) {
-        warning("'nrow(index)' is not consistent with 'num.neighbors'")
+    if (!is.null(distance) && !identical(dim(index), dim(distance))) {
+        stop("'index' and 'distance' should have the same dimensions")
     }
 }
 
