@@ -11,9 +11,15 @@ test_that("computeRnaQcMetrics works as expected", {
     expect_identical(qc$detected, Matrix::colSums(x > 0))
     expect_identical(qc$subsets$Mito, Matrix::colSums(x[sub$Mito,]) / qc$sum)
 
-    expect_error(computeRnaQcMetrics(x, list(TRUE)), "number of rows")
-    expect_error(computeRnaQcMetrics(x, list(-1)), "out-of-range")
-    expect_error(computeRnaQcMetrics(x, list("foo")), "no row names")
+    expect_error(computeRnaQcMetrics(x, list(-1)), "names")
+    expect_error(computeRnaQcMetrics(x, list(foo=TRUE)), "number of rows")
+    expect_error(computeRnaQcMetrics(x, list(foo=-1)), "out-of-range")
+    expect_error(computeRnaQcMetrics(x, list(foo="foo")), "no row names")
+
+    # Works with strings, where missing values are ignored..
+    rownames(x) <- sprintf("GENE-%s", seq_len(nrow(x)))
+    qc2 <- computeRnaQcMetrics(x, list(Mito=c("FOO", rownames(x)[sub$Mito], "BAR")))
+    expect_identical(qc, qc2)
 })
 
 test_that("suggestRnaQcThresholds works as expected", { 
@@ -45,6 +51,8 @@ test_that("suggestRnaQcThresholds works as expected with blocking", {
     num.mads <- 1.5
     thresholds <- suggestRnaQcThresholds(qc, block=block, num.mads=num.mads)
 
+    expect_identical(thresholds$block.ids, 1:3)
+
     # Check the thresholds.
     for (b in 1:3) {
         keep <- block == b
@@ -62,7 +70,7 @@ test_that("suggestRnaQcThresholds works as expected with blocking", {
     last <- block == 3
     last_observed <- filterRnaQcMetrics(
         thresholds,
-        list(sum=qc$sum[last], detected=qc$detected[last], subsets=list(qc$subsets[[1]][last])),
+        list(sum=qc$sum[last], detected=qc$detected[last], subsets=list(Mito=qc$subsets[[1]][last])),
         block=block[last]
     )
     expect_identical(observed[last], last_observed)
